#!/bin/sh
#
###########################################################################
#   Copyright (C) 2008-2009 by John Dickson
#   <captsens@gmail.com>
#
#   Licensed under the GNU Public Licence.  See LICENCE file that comes with this distribution
###########################################################################

# A simple script to back up JCR files to a tarball.
#
# This uses mkBackupList.py to create a list of only those files that *need* to be backed up.
# Output is a file called 'jcr-yyyymmdd.tar.gz' in $BACKUP_DIR
#
# IMPORTANT NOTE:
# The temporary file used for the files to be backed up is vulnerable to a temp file attack - be careful

# --------------------------------------------------------------------------
# The directory containing all the JCR Python modules (must be absolute)
# *** NOTE: Need to change this for each release! ***
JCR_INSTALL_BASE=/usr/lib/python2.5/site-packages/jcr-0.7.1.egg/jcr

# Full path to your JCR config file (must be absolute)
CONFIG_FILE=/some/path/to/jcr.ini

# The JCR base directory (containing 'projects', 'filesets', 'logs' etc.) (must be absolute)
JCR_BASE=/data/jcr

# The directory where backups are to be stored (must be absolute)
BACKUP_DIR=/var/backup/jcr

# Temporary file to which to write list (must be absolute)
BACKUP_LIST=/tmp/jcr-backup-filelist

# --------------------------------------------------------------------------
BACKUP_SCRIPT=$JCR_INSTALL_BASE/scripts/mkBackupList.py
if [ -! -f $BACKUP_SCRIPT ]; then
    echo "Cannot find script $BACKUP_SCRIPT"
    echo
    echo "Please correct the JCR_INSTALL_BASE in this script"
    exit 1
fi

if [ -! -f $CONFIG_FILE ]; then
    echo "Cannot find config file $CONFIG_FILE"
    echo
    echo "Please correct the CONFIG_FILE in this script"
    exit 1
fi

if [ -! -d $BACKUP_DIR ]; then
    echo "Cannot find backup directory $BACKUP_DIR"
    echo
    echo "Please correct the BACKUP_DIR in this script"
    exit 1
fi

cd $JCR_BASE
tarball=$BACKUP_DIR/jcr-`date +%Y%m%d`.tar.gz

python $BACKUP_SCRIPT $CONFIG_FILE > $BACKUP_LIST
tar cvz -T $BACKUP_LIST -f $tarball 
rm $BACKUP_LIST
