#!/usr/bin/env python

###########################################################################
#   Copyright (C) 2007 by John Dickson
#   <captsens@gmail.com>
#
#   Licensed under the GNU Public Licence.  See LICENCE file that comes with this distribution
###########################################################################

"""Script to prompt for and set admin password"""

import sys, os, getpass

from paste.deploy import appconfig
from pylons import config
from jcr.config.environment import load_environment

from jcr import model

# ------------------------------------------------------------------------------------------------
def usage():
    print """
Resets the administrator's password in the database

Usage:
    %s <configFile>
e.g.
    %s jcr.ini""" % (sys.argv[0], sys.argv[0])
    sys.exit(1)

# ------------------------------------------------------------------------------------------------
def main():
    if len(sys.argv) < 2:
        usage()

    filename = os.path.abspath(sys.argv[1])
    conf = appconfig('config:' + filename)
    load_environment(conf.global_conf, conf.local_conf)
    model.orm._buildSchema()

    try:
        print
        newPassword = getpass.getpass('Enter new administrator password: ')
        repeatNewPassword = getpass.getpass('Confirm new password: ')

        if newPassword != repeatNewPassword:
            print "ERROR: Passwords don't match"
            sys.exit(1)

        adminUser = model.systemuser.loadByUserName('admin')
        adminUser.setPassword(newPassword)
        model.orm.commit()

        print 'Password updated successfully'
    except KeyboardInterrupt:
        pass

# ------------------------------------------------------------------------------------------------
if __name__ == '__main__':
    main()