/****************************************************************************
 * Schema upgrade - script 1 of 2
 * Run this before any data upgrade scripts
 *
 * Schema:           jcr
 * DBMS:             postgres
 * Generated:        Sat Jul 30 18:33:51 2005
 *****************************************************************************/

/*===========================================================================
 * Changes for table: SystemUser
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
-- Drop all table constraints and indexes prior to renaming
ALTER TABLE systemuser
    DROP CONSTRAINT pk_user CASCADE;

ALTER TABLE SystemUser
    RENAME TO tmp_SystemUser;

CREATE TABLE SystemUser (
    systemId             INTEGER,
    username             VARCHAR(20),
    name                 VARCHAR(50),
    isSuperuser          CHAR(1),
    password             VARCHAR(20),
    email                VARCHAR(100)
);


/*===========================================================================
 * Changes for table: Project
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
-- Drop all table constraints and indexes prior to renaming
ALTER TABLE project
    DROP CONSTRAINT pk_project CASCADE;

ALTER TABLE project
    DROP CONSTRAINT fk_project_systemuser CASCADE;

ALTER TABLE Project
    RENAME TO tmp_Project;

CREATE TABLE Project (
    systemId             INTEGER,
    name                 VARCHAR(100),
    owner                INTEGER,
    createDate           TIMESTAMP,
    directory            VARCHAR(200),
    currentStatus        VARCHAR(10)
);


/*===========================================================================
 * Changes for table: ProjectFile
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
-- Drop all table constraints and indexes prior to renaming
ALTER TABLE projectfile
    DROP CONSTRAINT pk_projectfile CASCADE;

ALTER TABLE projectfile
    DROP CONSTRAINT fk_projectfile_project CASCADE;

DROP INDEX in_projectfile_project_path;

ALTER TABLE ProjectFile
    RENAME TO tmp_ProjectFile;

CREATE TABLE ProjectFile (
    systemId             INTEGER,
    project              INTEGER,
    path                 TEXT(500),
    changeType           CHAR(1)
);


/*===========================================================================
 * Changes for table: FileComment
 * Upgrade strategy: changeInPlace
 *===========================================================================*/
ALTER TABLE FileComment
    ADD reviewDate           TIMESTAMP;

ALTER TABLE FileComment
    ADD reviewComment        TEXT;

ALTER TABLE FileComment
    ADD reviewer             INTEGER;

ALTER TABLE FileComment
    ADD reviewDecision       VARCHAR(50);

ALTER TABLE FileComment
    ADD reviewActionOwner    INTEGER;

ALTER TABLE FileComment
    ADD actionDate           TIMESTAMP;

ALTER TABLE FileComment
    ADD actionComment        TEXT;

ALTER TABLE FileComment
    ADD actioner             INTEGER;

ALTER TABLE FileComment
    ADD actionsComplete      CHAR(1);

ALTER TABLE filecomment
    DROP CONSTRAINT fk_filecomment_projectfile CASCADE;

ALTER TABLE filecomment
    DROP CONSTRAINT fk_filecomment_systemuser CASCADE;


/*===========================================================================
 * Table:            Session
 * Description:      Contains details of HTTP sessions for logged-in users
 *===========================================================================*/
CREATE TABLE Session (
    systemId             INTEGER NOT NULL,
    sessionId            VARCHAR(20) NOT NULL,
    systemUser           INTEGER NOT NULL,
    lastRequest          TIMESTAMP NOT NULL,
    data                 TEXT
);

