/****************************************************************************
 * Schema upgrade - DML script
 * Run this after the -1.sql script, but before the -2.sql script.
 *
 * This script creates a FileSet row for each project original and modified directory,
 * unescapes comments columns in FileComment, and encodes values in FileComment.reviewDecision
 *
 * Schema:           jcr
 * DBMS:             postgres
 *****************************************************************************/

-- Add (temporarily) columns to FileSet to record the project and file set type
ALTER TABLE FileSet
    ADD tmp_project      INTEGER;

ALTER TABLE FileSet
    ADD tmp_fileSetType  CHAR(1);


-- Now populate the FileSet table from Project
INSERT INTO FileSet (systemId, owner, createDate, directory, baseline, tmp_project, tmp_fileSetType)
    SELECT nextval('tableids'), p.owner, p.createDate, 'projects/' || p.directory || '/original',
        'Original from ' || p.name, p.systemId, 'O'
    FROM Project p;

INSERT INTO FileSet (systemId, owner, createDate, directory, baseline, tmp_project, tmp_fileSetType)
    SELECT nextval('tableids'), p.owner, p.createDate, 'projects/' || p.directory || '/new',
        'Modified from ' || p.name, p.systemId, 'N'
    FROM Project p;


-- Re-establish the links back from the Projects
UPDATE Project
SET originalFileSet = (
    SELECT fs.systemId
    FROM FileSet fs
    WHERE fs.tmp_project = Project.systemId
        AND fs.tmp_fileSetType = 'O');

UPDATE Project
SET modifiedFileSet = (
    SELECT fs.systemId
    FROM FileSet fs
    WHERE fs.tmp_project = Project.systemId
        AND fs.tmp_fileSetType = 'N');


-- Finally, drop the temp columns
ALTER TABLE FileSet
    DROP tmp_project;

ALTER TABLE FileSet
    DROP tmp_fileSetType;


/*
    Unescape comment columns in FileComment

    - Change all <br> to \n
    - Change all &lt; to <
    - Change all &gt; to >
    - Change all &quot; to "
    - Change all &amp; to &
*/

UPDATE FileComment
SET comment = replace(comment, '<br>', '\n'),
    reviewComment = replace(reviewComment, '<br>', '\n'),
    actionComment = replace(actionComment, '<br>', '\n');

UPDATE FileComment
SET comment = replace(comment, '&lt;', '<'),
    reviewComment = replace(reviewComment, '&lt', '<'),
    actionComment = replace(actionComment, '&lt', '<');

UPDATE FileComment
SET comment = replace(comment, '&gt;', '>'),
    reviewComment = replace(reviewComment, '&gt;', '>'),
    actionComment = replace(actionComment, '&gt;', '>');

UPDATE FileComment
SET comment = replace(comment, '&quot;', '"'),
    reviewComment = replace(reviewComment, '&quot;', '"'),
    actionComment = replace(actionComment, '&quot;', '"');

UPDATE FileComment
SET comment = replace(comment, '&amp;', '&'),
    reviewComment = replace(reviewComment, '&amp;', '&'),
    actionComment = replace(actionComment, '&amp;', '&');


/*
    Encode reviewDecision in FileComment
*/

UPDATE FileComment
SET reviewDecision = 'NA'
WHERE reviewDecision = 'No action required';

UPDATE FileComment
SET reviewDecision = 'CI'
WHERE reviewDecision = 'Comment incorrect';

UPDATE FileComment
SET reviewDecision = 'UF'
WHERE reviewDecision = 'Urgent fix required';

UPDATE FileComment
SET reviewDecision = 'FR'
WHERE reviewDecision = 'Fix before release';

UPDATE FileComment
SET reviewDecision = 'ER'
WHERE reviewDecision = 'Raise ER';

UPDATE FileComment
SET reviewDecision = 'DR'
WHERE reviewDecision = 'Raise DR';


