/****************************************************************************
 * Schema upgrade - script 2 of 2
 * Run this after any data upgrade scripts
 *
 * Database:         jcr
 * DBMS:             postgres8
 *****************************************************************************/

/*===========================================================================
 * Changes for table: systemuser
 * Upgrade strategy: changeInPlace
 *===========================================================================*/
ALTER TABLE systemuser
    ADD CONSTRAINT pk_systemuser PRIMARY KEY (systemid);

-- Re-establish foreign key links.
-- Note that foreign keys to be recreated elsewhere are omitted
ALTER TABLE project
    ADD CONSTRAINT fk_project_systemuser FOREIGN KEY (owner) REFERENCES systemuser;

ALTER TABLE projectthread
    ADD CONSTRAINT fk_projectthread_systemuser FOREIGN KEY (owner) REFERENCES systemuser;

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcom_systemuser_reviewer FOREIGN KEY (reviewer) REFERENCES systemuser;

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcom_systemuser_actioner FOREIGN KEY (actioner) REFERENCES systemuser;

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecom_systemuser_reviewer FOREIGN KEY (reviewer) REFERENCES systemuser;

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecom_systemuser_actioner FOREIGN KEY (actioner) REFERENCES systemuser;


/*===========================================================================
 * Changes for table: fileset
 * Upgrade strategy: changeInPlace
 *===========================================================================*/
ALTER TABLE fileset
    ADD CONSTRAINT fk_fileset_systemuser FOREIGN KEY (owner) REFERENCES systemuser;


/*===========================================================================
 * Changes for table: project
 * Upgrade strategy: changeInPlace
 *===========================================================================*/
ALTER TABLE project
    ADD CONSTRAINT fk_project_originalfileset FOREIGN KEY (originalfileset) REFERENCES fileset;

ALTER TABLE project
    ADD CONSTRAINT fk_project_modifiedfileset FOREIGN KEY (modifiedfileset) REFERENCES fileset;


/*===========================================================================
 * Changes for table: projectstatus
 * Upgrade strategy: changeInPlace
 *===========================================================================*/
ALTER TABLE projectstatus
    ADD CONSTRAINT fk_projectstatus_project FOREIGN KEY (project) REFERENCES project;

ALTER TABLE projectstatus
    ADD CONSTRAINT fk_projectstatus_changedBy FOREIGN KEY (changedby) REFERENCES systemuser;


/*===========================================================================
 * Changes for table: projectthread
 * Upgrade strategy: create
 *===========================================================================*/
ALTER TABLE projectthread
    ADD CONSTRAINT pk_projectthread PRIMARY KEY (systemid);

ALTER TABLE projectthread
    ADD CONSTRAINT fk_projectthread_project FOREIGN KEY (project) REFERENCES project;

CREATE INDEX in_projectthread_owner ON projectthread (
    owner
);


/*===========================================================================
 * Changes for table: projectcomment
 * Upgrade strategy: create
 *===========================================================================*/
ALTER TABLE projectcomment
    ADD CONSTRAINT pk_projectcomment PRIMARY KEY (systemid);

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcomment_projectthread FOREIGN KEY (projectthread) REFERENCES projectthread;

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcomment_systemuser_owner FOREIGN KEY (owner) REFERENCES systemuser;

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcom_systemuser_revaction FOREIGN KEY (reviewactionowner) REFERENCES systemuser;

CREATE INDEX in_projectcomment_projectthread ON projectcomment (
    projectthread
);

CREATE INDEX in_projectcomment_owner ON projectcomment (
    owner
);

CREATE INDEX in_projectcomment_reviewer ON projectcomment (
    reviewer
);

CREATE INDEX in_projectcomment_revaction ON projectcomment (
    reviewactionowner
);

CREATE INDEX in_projectcomment_actioner ON projectcomment (
    actioner
);


/*===========================================================================
 * Changes for table: projectfile
 * Upgrade strategy: changeInPlace
 *===========================================================================*/
ALTER TABLE projectfile
    ADD CONSTRAINT fk_projectfile_project FOREIGN KEY (project) REFERENCES project;


/*===========================================================================
 * Changes for table: filecomment
 * Upgrade strategy: changeInPlace
 *===========================================================================*/
ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecomment_projectfile FOREIGN KEY (projectfile) REFERENCES projectfile;

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecomment_systemuser_owner FOREIGN KEY (owner) REFERENCES systemuser;

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecom_systemuser_revaction FOREIGN KEY (reviewactionowner) REFERENCES systemuser;


/*===========================================================================
 * Drop tables, views and sequences no longer needed
 *===========================================================================*/
