/****************************************************************************
 * Schema upgrade - script 1 of 2
 * Run this before any data upgrade scripts
 *
 * Database:         jcr
 * DBMS:             mysql
 *****************************************************************************/

/*===========================================================================
 * Changes for table: systemuser
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
-- Drop all table constraints and indexes prior to renaming
ALTER TABLE systemuser
    DROP PRIMARY KEY;

ALTER TABLE systemuser
    RENAME TO tmp_systemuser;

CREATE TABLE systemuser (
    systemid             INT AUTO_INCREMENT,
    username             VARCHAR(20),
    name                 VARCHAR(50),
    issuperuser          CHAR(1),
    password             VARCHAR(32),
    email                VARCHAR(100),
    enabled              CHAR(1)
)
TYPE=InnoDB
;


/*===========================================================================
 * Changes for table: fileset
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
-- Drop all table constraints and indexes prior to renaming
ALTER TABLE fileset
    DROP PRIMARY KEY;

ALTER TABLE fileset
    DROP FOREIGN KEY fk_fileset_systemuser;

ALTER TABLE fileset
    RENAME TO tmp_fileset;

CREATE TABLE fileset (
    systemid             INT AUTO_INCREMENT,
    owner                INT,
    createdate           DATETIME,
    directory            VARCHAR(500),
    baseline             VARCHAR(500)
)
TYPE=InnoDB
;


/*===========================================================================
 * Changes for table: project
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
-- Drop all table constraints and indexes prior to renaming
ALTER TABLE project
    DROP PRIMARY KEY;

ALTER TABLE project
    DROP FOREIGN KEY fk_project_systemuser;

ALTER TABLE project
    DROP FOREIGN KEY fk_project_originalfileset;

ALTER TABLE project
    DROP FOREIGN KEY fk_project_modifiedfileset;

ALTER TABLE project
    RENAME TO tmp_project;

CREATE TABLE project (
    systemid             INT AUTO_INCREMENT,
    name                 VARCHAR(100),
    owner                INT,
    createdate           DATETIME,
    directory            VARCHAR(200),
    currentstatus        VARCHAR(10),
    originalfileset      INT,
    modifiedfileset      INT,
    ignorewhitespace     CHAR(1),
    minimaldiff          CHAR(1),
    notes                LONGTEXT
)
TYPE=InnoDB
;


/*===========================================================================
 * Changes for table: projectstatus
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
-- Drop all table constraints and indexes prior to renaming
ALTER TABLE projectstatus
    DROP PRIMARY KEY;

ALTER TABLE projectstatus
    DROP FOREIGN KEY fk_projectstatus_project;

ALTER TABLE projectstatus
    DROP FOREIGN KEY fk_projectstatus_changedBy;

ALTER TABLE projectstatus
    RENAME TO tmp_projectstatus;

CREATE TABLE projectstatus (
    systemid             INT AUTO_INCREMENT,
    project              INT,
    changedby            INT,
    changedate           DATETIME,
    newstatus            VARCHAR(2)
)
TYPE=InnoDB
;


/*===========================================================================
 * Changes for table: projectthread
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
-- Drop all table constraints and indexes prior to renaming
ALTER TABLE projectthread
    DROP PRIMARY KEY;

ALTER TABLE projectthread
    DROP FOREIGN KEY fk_projectthread_project;

ALTER TABLE projectthread
    DROP FOREIGN KEY fk_projectthread_systemuser;

ALTER TABLE projectthread
    DROP INDEX in_projectthread_project;

ALTER TABLE projectthread
    DROP INDEX in_projectthread_owner;

ALTER TABLE projectthread
    RENAME TO tmp_projectthread;

CREATE TABLE projectthread (
    systemid             INT AUTO_INCREMENT,
    project              INT,
    owner                INT,
    threadtitle          VARCHAR(100)
)
TYPE=InnoDB
;


/*===========================================================================
 * Changes for table: projectcomment
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
-- Drop all table constraints and indexes prior to renaming
ALTER TABLE projectcomment
    DROP PRIMARY KEY;

ALTER TABLE projectcomment
    DROP FOREIGN KEY fk_projectcomment_projectthread;

ALTER TABLE projectcomment
    DROP FOREIGN KEY fk_projectcomment_systemuser_owner;

ALTER TABLE projectcomment
    DROP FOREIGN KEY fk_projectcom_systemuser_reviewer;

ALTER TABLE projectcomment
    DROP FOREIGN KEY fk_projectcom_systemuser_revaction;

ALTER TABLE projectcomment
    DROP FOREIGN KEY fk_projectcom_systemuser_actioner;

ALTER TABLE projectcomment
    DROP INDEX in_projectcomment_projectthread;

ALTER TABLE projectcomment
    DROP INDEX in_projectcomment_owner;

ALTER TABLE projectcomment
    DROP INDEX in_projectcomment_reviewer;

ALTER TABLE projectcomment
    DROP INDEX in_projectcomment_revaction;

ALTER TABLE projectcomment
    DROP INDEX in_projectcomment_actioner;

ALTER TABLE projectcomment
    RENAME TO tmp_projectcomment;

CREATE TABLE projectcomment (
    systemid             INT AUTO_INCREMENT,
    projectthread        INT,
    owner                INT,
    createdate           DATETIME,
    comment              LONGTEXT,
    reviewdate           DATETIME,
    reviewcomment        LONGTEXT,
    reviewer             INT,
    reviewdecision       VARCHAR(50),
    reviewactionowner    INT,
    actiondate           DATETIME,
    actioncomment        LONGTEXT,
    actioner             INT,
    actionscomplete      CHAR(1)
)
TYPE=InnoDB
;


/*===========================================================================
 * Changes for table: projectfile
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
-- Drop all table constraints and indexes prior to renaming
ALTER TABLE projectfile
    DROP PRIMARY KEY;

ALTER TABLE projectfile
    DROP FOREIGN KEY fk_projectfile_project;

ALTER TABLE projectfile
    DROP INDEX in_projectfile_project_path;

ALTER TABLE projectfile
    RENAME TO tmp_projectfile;

CREATE TABLE projectfile (
    systemid             INT AUTO_INCREMENT,
    project              INT,
    path                 VARCHAR(500),
    originalpath         VARCHAR(500),
    changetype           CHAR(1),
    notes                LONGTEXT,
    reviewpriority       SMALLINT
)
TYPE=InnoDB
;


/*===========================================================================
 * Changes for table: filecomment
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
-- Drop all table constraints and indexes prior to renaming
ALTER TABLE filecomment
    DROP PRIMARY KEY;

ALTER TABLE filecomment
    DROP FOREIGN KEY fk_filecomment_projectfile;

ALTER TABLE filecomment
    DROP FOREIGN KEY fk_filecomment_systemuser_owner;

ALTER TABLE filecomment
    DROP FOREIGN KEY fk_filecom_systemuser_reviewer;

ALTER TABLE filecomment
    DROP FOREIGN KEY fk_filecom_systemuser_revaction;

ALTER TABLE filecomment
    DROP FOREIGN KEY fk_filecom_systemuser_actioner;

ALTER TABLE filecomment
    DROP INDEX in_filecomment_owner;

ALTER TABLE filecomment
    DROP INDEX in_filecomment_reviewer;

ALTER TABLE filecomment
    DROP INDEX in_filecomment_revaction;

ALTER TABLE filecomment
    DROP INDEX in_filecomment_actioner;

ALTER TABLE filecomment
    RENAME TO tmp_filecomment;

CREATE TABLE filecomment (
    systemid             INT AUTO_INCREMENT,
    projectfile          INT,
    linenumber           INT,
    owner                INT,
    createdate           DATETIME,
    comment              LONGTEXT,
    reviewdate           DATETIME,
    reviewcomment        LONGTEXT,
    reviewer             INT,
    reviewdecision       VARCHAR(50),
    reviewactionowner    INT,
    actiondate           DATETIME,
    actioncomment        LONGTEXT,
    actioner             INT,
    actionscomplete      CHAR(1)
)
TYPE=InnoDB
;

