/****************************************************************************
 * Schema upgrade - script 2 of 2
 * Run this after any data upgrade scripts
 *
 * Database:         jcr
 * DBMS:             mysql
 *****************************************************************************/

/*===========================================================================
 * Changes for table: systemuser
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
ALTER TABLE systemuser
     CHANGE COLUMN systemid systemid             INT AUTO_INCREMENT NOT NULL;

ALTER TABLE systemuser
     CHANGE COLUMN username username             VARCHAR(20) NOT NULL;

ALTER TABLE systemuser
     CHANGE COLUMN name name                 VARCHAR(50) NOT NULL;

ALTER TABLE systemuser
     CHANGE COLUMN issuperuser issuperuser          CHAR(1) NOT NULL;

ALTER TABLE systemuser
     CHANGE COLUMN password password             VARCHAR(32) NOT NULL;

ALTER TABLE systemuser
     CHANGE COLUMN enabled enabled              CHAR(1) NOT NULL;

ALTER TABLE systemuser
    ADD CONSTRAINT pk_systemuser PRIMARY KEY (systemid);

-- Drop temporary table
ALTER TABLE systemuser
    DROP FOREIGN KEY fk_fileset_systemuser;

ALTER TABLE systemuser
    DROP FOREIGN KEY fk_project_systemuser;

ALTER TABLE systemuser
    DROP FOREIGN KEY fk_projectstatus_changedBy;

ALTER TABLE systemuser
    DROP FOREIGN KEY fk_projectthread_systemuser;

ALTER TABLE systemuser
    DROP FOREIGN KEY fk_projectcomment_systemuser_owner;

ALTER TABLE systemuser
    DROP FOREIGN KEY fk_projectcom_systemuser_reviewer;

ALTER TABLE systemuser
    DROP FOREIGN KEY fk_projectcom_systemuser_revaction;

ALTER TABLE systemuser
    DROP FOREIGN KEY fk_projectcom_systemuser_actioner;

ALTER TABLE systemuser
    DROP FOREIGN KEY fk_filecomment_systemuser_owner;

ALTER TABLE systemuser
    DROP FOREIGN KEY fk_filecom_systemuser_reviewer;

ALTER TABLE systemuser
    DROP FOREIGN KEY fk_filecom_systemuser_revaction;

ALTER TABLE systemuser
    DROP FOREIGN KEY fk_filecom_systemuser_actioner;

DROP TABLE tmp_systemuser CASCADE;

-- Re-establish foreign key links.
-- Note that foreign keys to be recreated elsewhere are omitted
ALTER TABLE fileset
    ADD CONSTRAINT fk_fileset_systemuser FOREIGN KEY (owner) REFERENCES systemuser(systemid);

ALTER TABLE project
    ADD CONSTRAINT fk_project_systemuser FOREIGN KEY (owner) REFERENCES systemuser(systemid);

ALTER TABLE projectstatus
    ADD CONSTRAINT fk_projectstatus_changedBy FOREIGN KEY (changedby) REFERENCES systemuser(systemid);

ALTER TABLE projectthread
    ADD CONSTRAINT fk_projectthread_systemuser FOREIGN KEY (owner) REFERENCES systemuser(systemid);

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcomment_systemuser_owner FOREIGN KEY (owner) REFERENCES systemuser(systemid);

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcom_systemuser_reviewer FOREIGN KEY (reviewer) REFERENCES systemuser(systemid);

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcom_systemuser_revaction FOREIGN KEY (reviewactionowner) REFERENCES systemuser(systemid);

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcom_systemuser_actioner FOREIGN KEY (actioner) REFERENCES systemuser(systemid);

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecomment_systemuser_owner FOREIGN KEY (owner) REFERENCES systemuser(systemid);

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecom_systemuser_reviewer FOREIGN KEY (reviewer) REFERENCES systemuser(systemid);

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecom_systemuser_revaction FOREIGN KEY (reviewactionowner) REFERENCES systemuser(systemid);

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecom_systemuser_actioner FOREIGN KEY (actioner) REFERENCES systemuser(systemid);


/*===========================================================================
 * Changes for table: fileset
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
ALTER TABLE fileset
     CHANGE COLUMN systemid systemid             INT AUTO_INCREMENT NOT NULL;

ALTER TABLE fileset
     CHANGE COLUMN owner owner                INT NOT NULL;

ALTER TABLE fileset
     CHANGE COLUMN createdate createdate           DATETIME NOT NULL;

ALTER TABLE fileset
    ADD CONSTRAINT pk_fileset PRIMARY KEY (systemid);

ALTER TABLE fileset
    ADD CONSTRAINT fk_fileset_systemuser FOREIGN KEY (owner) REFERENCES systemuser(systemid);

-- Drop temporary table
ALTER TABLE fileset
    DROP FOREIGN KEY fk_project_originalfileset;

ALTER TABLE fileset
    DROP FOREIGN KEY fk_project_modifiedfileset;

DROP TABLE tmp_fileset CASCADE;

-- Re-establish foreign key links.
-- Note that foreign keys to be recreated elsewhere are omitted
ALTER TABLE project
    ADD CONSTRAINT fk_project_originalfileset FOREIGN KEY (originalfileset) REFERENCES fileset(systemid);

ALTER TABLE project
    ADD CONSTRAINT fk_project_modifiedfileset FOREIGN KEY (modifiedfileset) REFERENCES fileset(systemid);


/*===========================================================================
 * Changes for table: project
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
ALTER TABLE project
     CHANGE COLUMN systemid systemid             INT AUTO_INCREMENT NOT NULL;

ALTER TABLE project
     CHANGE COLUMN name name                 VARCHAR(100) NOT NULL;

ALTER TABLE project
     CHANGE COLUMN owner owner                INT NOT NULL;

ALTER TABLE project
     CHANGE COLUMN createdate createdate           DATETIME NOT NULL;

ALTER TABLE project
     CHANGE COLUMN directory directory            VARCHAR(200) NOT NULL;

ALTER TABLE project
     CHANGE COLUMN currentstatus currentstatus        VARCHAR(10) NOT NULL;

ALTER TABLE project
    ADD CONSTRAINT pk_project PRIMARY KEY (systemid);

ALTER TABLE project
    ADD CONSTRAINT fk_project_systemuser FOREIGN KEY (owner) REFERENCES systemuser(systemid);

ALTER TABLE project
    ADD CONSTRAINT fk_project_originalfileset FOREIGN KEY (originalfileset) REFERENCES fileset(systemid);

ALTER TABLE project
    ADD CONSTRAINT fk_project_modifiedfileset FOREIGN KEY (modifiedfileset) REFERENCES fileset(systemid);

-- Drop temporary table
ALTER TABLE project
    DROP FOREIGN KEY fk_projectstatus_project;

ALTER TABLE project
    DROP FOREIGN KEY fk_projectthread_project;

ALTER TABLE project
    DROP FOREIGN KEY fk_projectfile_project;

DROP TABLE tmp_project CASCADE;

-- Re-establish foreign key links.
-- Note that foreign keys to be recreated elsewhere are omitted
ALTER TABLE projectstatus
    ADD CONSTRAINT fk_projectstatus_project FOREIGN KEY (project) REFERENCES project(systemid);

ALTER TABLE projectthread
    ADD CONSTRAINT fk_projectthread_project FOREIGN KEY (project) REFERENCES project(systemid);

ALTER TABLE projectfile
    ADD CONSTRAINT fk_projectfile_project FOREIGN KEY (project) REFERENCES project(systemid);


/*===========================================================================
 * Changes for table: projectstatus
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
ALTER TABLE projectstatus
     CHANGE COLUMN systemid systemid             INT AUTO_INCREMENT NOT NULL;

ALTER TABLE projectstatus
     CHANGE COLUMN project project              INT NOT NULL;

ALTER TABLE projectstatus
     CHANGE COLUMN changedby changedby            INT NOT NULL;

ALTER TABLE projectstatus
     CHANGE COLUMN changedate changedate           DATETIME NOT NULL;

ALTER TABLE projectstatus
     CHANGE COLUMN newstatus newstatus            VARCHAR(2) NOT NULL;

ALTER TABLE projectstatus
    ADD CONSTRAINT pk_projectstatus PRIMARY KEY (systemid);

ALTER TABLE projectstatus
    ADD CONSTRAINT fk_projectstatus_project FOREIGN KEY (project) REFERENCES project(systemid);

ALTER TABLE projectstatus
    ADD CONSTRAINT fk_projectstatus_changedBy FOREIGN KEY (changedby) REFERENCES systemuser(systemid);

-- Drop temporary table
DROP TABLE tmp_projectstatus CASCADE;


/*===========================================================================
 * Changes for table: projectthread
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
ALTER TABLE projectthread
     CHANGE COLUMN systemid systemid             INT AUTO_INCREMENT NOT NULL;

ALTER TABLE projectthread
     CHANGE COLUMN project project              INT NOT NULL;

ALTER TABLE projectthread
     CHANGE COLUMN owner owner                INT NOT NULL;

ALTER TABLE projectthread
     CHANGE COLUMN threadtitle threadtitle          VARCHAR(100) NOT NULL;

ALTER TABLE projectthread
    ADD CONSTRAINT pk_projectthread PRIMARY KEY (systemid);

ALTER TABLE projectthread
    ADD CONSTRAINT fk_projectthread_project FOREIGN KEY (project) REFERENCES project(systemid);

ALTER TABLE projectthread
    ADD CONSTRAINT fk_projectthread_systemuser FOREIGN KEY (owner) REFERENCES systemuser(systemid);

CREATE INDEX in_projectthread_project ON projectthread (
    project
);

CREATE INDEX in_projectthread_owner ON projectthread (
    owner
);

-- Drop temporary table
ALTER TABLE projectthread
    DROP FOREIGN KEY fk_projectcomment_projectthread;

DROP TABLE tmp_projectthread CASCADE;

-- Re-establish foreign key links.
-- Note that foreign keys to be recreated elsewhere are omitted
ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcomment_projectthread FOREIGN KEY (projectthread) REFERENCES projectthread(systemid);


/*===========================================================================
 * Changes for table: projectcomment
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
ALTER TABLE projectcomment
     CHANGE COLUMN systemid systemid             INT AUTO_INCREMENT NOT NULL;

ALTER TABLE projectcomment
     CHANGE COLUMN projectthread projectthread        INT NOT NULL;

ALTER TABLE projectcomment
     CHANGE COLUMN owner owner                INT NOT NULL;

ALTER TABLE projectcomment
     CHANGE COLUMN createdate createdate           DATETIME NOT NULL;

ALTER TABLE projectcomment
     CHANGE COLUMN comment comment              LONGTEXT NOT NULL;

ALTER TABLE projectcomment
    ADD CONSTRAINT pk_projectcomment PRIMARY KEY (systemid);

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcomment_projectthread FOREIGN KEY (projectthread) REFERENCES projectthread(systemid);

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcomment_systemuser_owner FOREIGN KEY (owner) REFERENCES systemuser(systemid);

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcom_systemuser_reviewer FOREIGN KEY (reviewer) REFERENCES systemuser(systemid);

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcom_systemuser_revaction FOREIGN KEY (reviewactionowner) REFERENCES systemuser(systemid);

ALTER TABLE projectcomment
    ADD CONSTRAINT fk_projectcom_systemuser_actioner FOREIGN KEY (actioner) REFERENCES systemuser(systemid);

CREATE INDEX in_projectcomment_projectthread ON projectcomment (
    projectthread
);

CREATE INDEX in_projectcomment_owner ON projectcomment (
    owner
);

CREATE INDEX in_projectcomment_reviewer ON projectcomment (
    reviewer
);

CREATE INDEX in_projectcomment_revaction ON projectcomment (
    reviewactionowner
);

CREATE INDEX in_projectcomment_actioner ON projectcomment (
    actioner
);

-- Drop temporary table
DROP TABLE tmp_projectcomment CASCADE;


/*===========================================================================
 * Changes for table: projectfile
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
ALTER TABLE projectfile
     CHANGE COLUMN systemid systemid             INT AUTO_INCREMENT NOT NULL;

ALTER TABLE projectfile
     CHANGE COLUMN project project              INT NOT NULL;

ALTER TABLE projectfile
     CHANGE COLUMN path path                 VARCHAR(500) NOT NULL;

ALTER TABLE projectfile
     CHANGE COLUMN changetype changetype           CHAR(1) NOT NULL;

ALTER TABLE projectfile
    ADD CONSTRAINT pk_projectfile PRIMARY KEY (systemid);

ALTER TABLE projectfile
    ADD CONSTRAINT fk_projectfile_project FOREIGN KEY (project) REFERENCES project(systemid);

CREATE UNIQUE INDEX in_projectfile_project_path ON projectfile (
    project,
    path(500)
);

-- Drop temporary table
ALTER TABLE projectfile
    DROP FOREIGN KEY fk_filecomment_projectfile;

DROP TABLE tmp_projectfile CASCADE;

-- Re-establish foreign key links.
-- Note that foreign keys to be recreated elsewhere are omitted
ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecomment_projectfile FOREIGN KEY (projectfile) REFERENCES projectfile(systemid);


/*===========================================================================
 * Changes for table: filecomment
 * Upgrade strategy: changeByCopy
 *===========================================================================*/
ALTER TABLE filecomment
     CHANGE COLUMN systemid systemid             INT AUTO_INCREMENT NOT NULL;

ALTER TABLE filecomment
     CHANGE COLUMN projectfile projectfile          INT NOT NULL;

ALTER TABLE filecomment
     CHANGE COLUMN linenumber linenumber           INT NOT NULL;

ALTER TABLE filecomment
     CHANGE COLUMN owner owner                INT NOT NULL;

ALTER TABLE filecomment
     CHANGE COLUMN createdate createdate           DATETIME NOT NULL;

ALTER TABLE filecomment
     CHANGE COLUMN comment comment              LONGTEXT NOT NULL;

ALTER TABLE filecomment
    ADD CONSTRAINT pk_filecomment PRIMARY KEY (systemid);

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecomment_projectfile FOREIGN KEY (projectfile) REFERENCES projectfile(systemid);

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecomment_systemuser_owner FOREIGN KEY (owner) REFERENCES systemuser(systemid);

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecom_systemuser_reviewer FOREIGN KEY (reviewer) REFERENCES systemuser(systemid);

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecom_systemuser_revaction FOREIGN KEY (reviewactionowner) REFERENCES systemuser(systemid);

ALTER TABLE filecomment
    ADD CONSTRAINT fk_filecom_systemuser_actioner FOREIGN KEY (actioner) REFERENCES systemuser(systemid);

CREATE INDEX in_filecomment_owner ON filecomment (
    owner
);

CREATE INDEX in_filecomment_reviewer ON filecomment (
    reviewer
);

CREATE INDEX in_filecomment_revaction ON filecomment (
    reviewactionowner
);

CREATE INDEX in_filecomment_actioner ON filecomment (
    actioner
);

-- Drop temporary table
DROP TABLE tmp_filecomment CASCADE;


/*===========================================================================
 * Drop tables, views and sequences no longer needed
 *===========================================================================*/
DROP TABLE systemids CASCADE;

