  #!/bin/sh
  
  # Package up the build, including:
  # - check and confirm the version number
  # - ensure everything checked in to svn
  # - build the java module
  # - build the documentation
  # - copy documentation, samples etc. to the output/dist directory
  # - zip up the distribution
  
  #set -xv
  
  ANT_BUILD_FILE=build.xml
  CLICHART_BIN_FILE=resource/bin/clichart
  CLICHART_BAT_FILE=resource/bin/clichart.bat
  
  PACKAGE_OUTPUT_DIR=output/package
  
  # for some reason, doesn't build with 1.6
  export JAVA_HOME=/usr/java/jdk1.5.0_10
  
  # ============================================================
  function usage() {
      cat << EOM
  Build and package clichart into zip (binary only, not source)
  EOM
      exit 1
  }
  
  # ============================================================
  function checkSvnStatus() {
      # disallow if haven't checked everything into svn
      uncommittedFiles=`svn status | egrep -c "^[AMD]"`
      if [ $uncommittedFiles -ne 0 ]; then
          echo "You still have uncommitted changes in subversion"
          echo
          echo "Are you SURE you want to continue? [y/N]"
          read okToContinue
          if [ "$okToContinue" != "y" ]; then
              echo "User cancel"
              exit
          fi
      fi
  }
  
  # ============================================================
  function getVersionNumber() {
      # determine the current version number, and set as $versionNum
      # Note that this is taken from build.xml, and checked against the shell and batch files
      versionNum=`grep "property.*name=.clichart-version" $ANT_BUILD_FILE \
              | awk '{print substr($3, 7)}' | sed -e 's/"//g'`
      echo "OK to package using existing version $versionNum? [y/N]"
      read okToContinue
      if [ "$okToContinue" != "y" ]; then
          echo "User cancel"
          exit
      fi
  }
  
  # ============================================================
  function checkVersionNumber() {
      # Check $versionNum against the jar file name in the clichart shell script and batch file
      shellVersionNum=`grep "clichart-.*jar" $CLICHART_BIN_FILE \
              | sed -e 's/CLICHART=clichart-//' -e 's/.jar//'`
      if [ "$versionNum" != "$shellVersionNum" ]; then
          echo "Version number ($shellVersionNum) does not match in file $CLICHART_BIN_FILE"
          exit
      fi
  
      batchVersionNum=`grep "clichart-.*jar" $CLICHART_BAT_FILE \
              | sed -e 's/set CLICHART=clichart-//' -e 's/.jar//'`
      if [ "$versionNum" != "$batchVersionNum" ]; then
          echo "Version number ($batchVersionNum) does not match in file $CLICHART_BAT_FILE"
          exit
      fi
  }
  
  # ============================================================
  function createPackageTree() {
      # copy all the required files to the packaging dir, ready to be zipped
      baseDir=$1
  
      echo "Building with ant"
      ant clean package
  
      echo
      echo "Generating documentation"
      bin/buildDoco.sh
  
      echo "Copying files"
      mkdir -p $baseDir
      cp -a output/dist/* $baseDir
  
      # scripts
      mkdir $baseDir/bin
      cp -a resource/bin/clichart resource/bin/clichart.bat resource/bin/*.py $baseDir/bin
  
      # docs
      mkdir $baseDir/docs
      cp -a docs/output/* $baseDir/docs
  
      # samples
      mkdir $baseDir/samples
      cp -a samples/*.csv $baseDir/samples
+     cp -a samples/*.txt $baseDir/samples
      cp -a samples/*.log $baseDir/samples
  
      # misc
      cp CHANGES.txt README.txt LICENCE.txt $baseDir
  }
  
  # ============================================================
  function package() {
      (cd $PACKAGE_OUTPUT_DIR; zip -r ../clichart-$versionNum.zip *)
  }
  
  # ============================================================
  cd `dirname $0`/..
  
  if [ "$1" = "-h" ]; then
      usage
  fi
  
  # sets as $versionNum
  getVersionNumber
  
  checkVersionNumber
  
  checkSvnStatus
  
  baseDir=$PACKAGE_OUTPUT_DIR/clichart-$versionNum
  
  createPackageTree $baseDir
  
  package $baseDir
  
  echo "Build source package as well? [y/N]"
  read okToContinue
  if [ "$okToContinue" = "y" ]; then
      bin/packageSrcBuild.sh $versionNum
  fi
