  /* (C) Copyright 2006, by John Dickson
   *
   * Project Info:  http://clichart.sourceforge.net/
   *
   * This library is free software; you can redistribute it and/or modify it
   * under the terms of the GNU Lesser General Public License as published by
   * the Free Software Foundation; either version 2.1 of the License, or
   * (at your option) any later version.
   *
   * This library is distributed in the hope that it will be useful, but
   * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
   * License for more details.
   *
   * You should have received a copy of the GNU Lesser General Public
   * License along with this library; if not, write to the Free Software
   * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
   * USA.
   *
-  * $Id: Main.java 541 2007-04-01 01:21:37Z johnd $
?                    ^^          ^    -  ^
+  * $Id: Main.java 552 2007-04-08 01:15:47Z johnd $
?                    ^^          ^     + ^
   */
  
  package net.sf.clichart.main;
  
+ import net.sf.clichart.chart.ChartSaverException;
+ import net.sf.clichart.chart.Options;
- import net.sf.clichart.data.LineParser;
- import net.sf.clichart.data.DataParser;
- import net.sf.clichart.data.TimeDataParser;
- import net.sf.clichart.data.WhiteSpaceLineParser;
  import net.sf.clichart.data.InvalidDataException;
+ import net.sf.clichart.main.cliserver.CliServer;
- import net.sf.clichart.data.CsvLineParser;
- import net.sf.clichart.data.ValueDataParser;
- import net.sf.clichart.data.AbstractDataParser;
- import net.sf.clichart.chart.AbstractChartBuilder;
- import net.sf.clichart.chart.TimeSeriesChartBuilder;
- import net.sf.clichart.chart.Options;
- import net.sf.clichart.chart.XYChartBuilder;
- import net.sf.clichart.chart.ChartSaver;
- import net.sf.clichart.chart.ChartSaverException;
  
- import java.io.InputStreamReader;
- import java.io.File;
- import java.io.Reader;
- import java.io.FileReader;
- import java.io.FileNotFoundException;
  import java.io.IOException;
- 
- import org.jfree.chart.JFreeChart;
- import org.jfree.chart.ChartUtilities;
- 
- import javax.swing.*;
  
  /**
   * Main class for executing clichart from the command line, and for use as a library.
   *
   * <p>Can also be used to drive clichart from Java, as a library.  Several of the methods can be overridden by
   * a subclass if required.
   *
   * <p>The incoming data is parsed by a DataParser, which has an AbstractChartBuilder linked to it as a data sink for
   * each chart axis.  Once parsing of the data is finished, the chart builder is responsible for building the chart
   * on request. 
   *
   * @author johnd
   */
  public class Main {
      /* ========================================================================
       *
       * Class (static) variables.
       */
  
      /* ========================================================================
       *
       * Instance variables.
       */
  
-     /** Used to parse the input data */
-     private AbstractDataParser m_dataParser;
- 
-     /** The main chart builder */
-     private AbstractChartBuilder m_chartBuilder;
- 
-     /** Chart builder used for the second axis (if any) */
-     private AbstractChartBuilder m_secondAxisBuilder = null;
  
      /* ========================================================================
       *
       * Constructors
       */
  
      /* ========================================================================
       *
       * Static methods
       */
  
      public static void main(String[] args) {
          OptionParser optionParser = new OptionParser();
          try {
              Options options = optionParser.getOptions(args);
-             new Main().parseDataAndProcessChart(options);
+ 
+             if (options.isCliServer()) {
+                 CliServer cliServer = new CliServer();
+                 cliServer.setChartGenerator(new Main().buildChartGenerator());
+                 cliServer.interact(System.in, System.out);
+ 
+             } else {
+                 new Main().buildChartGenerator().generateChart(options);
+             }
  
          } catch (InvalidOptionsException e) {
              optionParser.showHelp(e.getMessage());
          } catch (ShowUsageException e) {
              optionParser.showHelp(null);
          } catch (InvalidDataException e) {
              System.out.println("Invalid data: " + e.getMessage());
          } catch (ChartSaverException e) {
              System.out.println("Error saving chart: " + e.getMessage());
          } catch (IOException e) {
              System.out.println("I/O error reading or writing: " + e.toString());
          }
      }
  
  
      /* ========================================================================
       *
       * Public methods
       */
  
-     /**
-      * The main method to parse the provided data (from the supplied input file, or from stdin if null), and either
-      * display a chart in an interactive window or save it to a file (depending on the present of an output path in the
-      * options).
-      *
-      * @param options  Options used for parsing data and generating chart
-      * @throws IOException If not able to read input data or write chart
-      * @throws InvalidDataException Input data was invalid (or didn't match the options provided)
-      * @throws InvalidOptionsException
-      * @throws ChartSaverException
-      */
-     public void parseDataAndProcessChart(Options options)
-             throws IOException, InvalidDataException, InvalidOptionsException, ChartSaverException {
-         JFreeChart chart = buildChart(options);
- 
-         if (options.getFileOutputPath() != null) {
-             createChartSaver(chart, options).saveChart(new File(options.getFileOutputPath()));
-         } else {
-             JFrame frame = createChartFrame(chart, options);
-             frame.setVisible(true);
-         }
-     }
  
      /* ========================================================================
       *
       * Protected / package-private methods
       */
  
-     /**
-      * Return a ChartSaver for saving the chart to a file
-      */
-     protected ChartSaver createChartSaver(JFreeChart chart, Options options) {
-         return new ChartSaver(chart, options.getChartWidth(), options.getChartHeight());
-     }
- 
-     /**
-      * Return a frame displaying the supplied chart
-      */
-     protected JFrame createChartFrame(JFreeChart chart, Options options) {
-         ChartFrame frame = new ChartFrame();
-         frame.setInitialWidth(options.getChartWidth());
-         frame.setInitialHeight(options.getChartHeight());
-         frame.setChart(chart);
-         return frame;
-     }
- 
-     /**
-      * Create and return an appropriate chart builder, based on the options provided
-      */
-     protected AbstractChartBuilder buildChartBuilder(Options options) {
-         if (options.getChartXType() == Options.X_TYPE_NONE || options.getChartXType() == Options.X_TYPE_VALUE) {
-             return new XYChartBuilder(options);
-         } else {
-             return new TimeSeriesChartBuilder(options);
-         }
-     }
- 
-     /**
-      * Create and return an appropriate data parser, based on the options provided.  Note that the chartBuilder must
-      * be plugged into the data parser as its data sink.
-      */
-     protected AbstractDataParser buildDataParser(Options options, AbstractChartBuilder chartbuider) {
-         LineParser lineParser = null;
-         if (options.getDataSeparatorType() == Options.DATA_SEP_CSV) {
-             lineParser = new CsvLineParser();
-         } else {
-             lineParser = new WhiteSpaceLineParser();
-         }
- 
-         if (options.getChartXType() == Options.X_TYPE_NONE) {
-             // no x values
-             int[] dataColumnIndexes = getYColumnIndexes(options, 0);
-             return new ValueDataParser(lineParser, -1, dataColumnIndexes, options.hasHeaderRow(),
-                     options.ignoreMissingColumns(), chartbuider);
- 
-         } else if (options.getChartXType() == Options.X_TYPE_VALUE) {
-             int xColumnIndex = options.getColumnIndexes()[0];
-             int[] dataColumnIndexes = getYColumnIndexes(options, 1);
- 
-             return new ValueDataParser(lineParser, xColumnIndex, dataColumnIndexes, options.hasHeaderRow(),
-                     options.ignoreMissingColumns(), chartbuider);
- 
-         } else {
-             int xColumnIndex = options.getColumnIndexes()[0];
-             int[] dataColumnIndexes = getYColumnIndexes(options, 1);
- 
-             return new TimeDataParser(lineParser, options.getDateFormat(), xColumnIndex, dataColumnIndexes,
-                     options.hasHeaderRow(), options.ignoreMissingColumns(), chartbuider);
-         }
-     }
  
      /* ========================================================================
       *
       * Private methods
       */
  
-     private JFreeChart buildChart(Options options) throws IOException, InvalidDataException, InvalidOptionsException {
-         m_chartBuilder = buildChartBuilder(options);
-         m_dataParser = buildDataParser(options, m_chartBuilder);
- 
-         if (options.getSecondAxisColumnIndexes() != null) {
-             // need to use the same type as the main chartBuilder
-             m_secondAxisBuilder = buildChartBuilder(options);
-             m_dataParser.addSecondAxis(options.getSecondAxisColumnIndexes(), m_secondAxisBuilder);
-         }
- 
-         m_dataParser.parse(buildInputReader(options));
-         JFreeChart chart = m_chartBuilder.getChart(options);
- 
-         if (m_secondAxisBuilder != null) {
-             m_secondAxisBuilder.addSecondAxis(chart, options);
-         }
-         return chart;
-     }
- 
- 
-     private int[] getYColumnIndexes(Options options, int startIndex) {
-         int[] dataColumnIndexes = new int[options.getColumnIndexes().length - startIndex];
-         for (int i = 0; i < dataColumnIndexes.length; i++) {
-             dataColumnIndexes[i] = options.getColumnIndexes()[i + startIndex];
-         }
-         return dataColumnIndexes;
-     }
- 
      /**
-      * Note that the file is never closed, so this is only appropriate when parsing 1 file then exiting
+      * Package private for testing
       */
+     private ChartGenerator buildChartGenerator() {
+         return new DefaultChartGenerator();
-     private Reader buildInputReader(Options options) throws InvalidOptionsException {
-         String inputPath = options.getInputPath();
- 
-         if (inputPath != null) {
-             try {
-                 return new FileReader(inputPath);
-             } catch (FileNotFoundException e) {
-                 throw new InvalidOptionsException("File not found: " + inputPath);
-             }
-         } else {
-             //System.err.println("Reading from stdin");
-             return new InputStreamReader(System.in);
-         }
      }
  
  }