#!/bin/sh

# Package up the src build.  Assumes that the binary distribution has already been built.

#set -xv

PACKAGE_OUTPUT_DIR=output/package


# ============================================================
function usage() {
    cat << EOM
Package clichart source into zip

Usage:
  packageSrcBuild.sh <versionNumber>
EOM
    exit 1
}



# ============================================================
function createPackageTree() {
    # copy all the required files to the packaging dir, ready to be zipped
    # Main reason for this is that zip is crap on excludes, so do the copy manually
    baseDir=$1

    if [ -d $baseDir ]; then
        rm -fR $baseDir
    fi
    mkdir -p $baseDir

    # copy everything
    cp -a LICENCE.txt README.txt CHANGES.txt src test build.xml TODO.txt DistChecklist.txt bin $baseDir

    mkdir $baseDir/resource
    cp -a resource/bin resource/jar $baseDir/resource

    mkdir $baseDir/lib
    cp -a lib/easymock* lib/junit* $baseDir/lib

    mkdir $baseDir/docs
    cp -a docs/html docs/rst docs/*.css docs/homepage docs/images $baseDir/docs

    # now prune all the stuff we don't want
    find $baseDir -name "*~" -exec rm {} \;
    find $baseDir -name "*.pyc" -exec rm {} \;
    find $baseDir -name "*.class" -exec rm {} \;
    find $baseDir -name ".svn" -exec rm -fR {} \;
}

# ============================================================
function package() {
    (cd $PACKAGE_OUTPUT_DIR; rm ../clichart-src-$versionNum.zip; zip -r ../clichart-src-$versionNum.zip \
            clichart-src-$versionNum/*)
}

# ============================================================
cd `dirname $0`/..

if [ "$1" = "" -o "$1" = "-h" ]; then
    usage
fi
versionNum=$1

baseDir=$PACKAGE_OUTPUT_DIR/clichart-src-$versionNum

createPackageTree $baseDir

package $baseDir

