/* (C) Copyright 2006, by John Dickson
 *
 * Project Info:  http://clichart.sourceforge.net/
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 * $Id: OptionsBean.java 559 2007-04-14 02:51:36Z johnd $
 */

package net.sf.clichart.chart;

/**
 * A simple options Java bean, used for tests (?)
 *
 * @author johnd
 */
public class OptionsBean implements Options {

    /* ========================================================================
     *
     * Class (static) variables.
     */

    /* ========================================================================
     *
     * Instance variables.
     */

    private int m_dataSeparatorType = Options.DATA_SEP_WHITE_SPACE;

    private String m_dateFormat = DEFAULT_DATE_FORMAT;

    private boolean m_headerRow = false;

    private boolean m_ignoreMissingColumns = false;
    private boolean m_ignoreDuplicateValues = false;

    private int[] m_columnIndexes = DEFAULT_COLUMN_INDEXES;
    private int[] m_secondAxisColumnIndexes = null;

    private int m_chartXType = DEFAULT_X_TYPE;

    private String m_fileOutputPath = null;

    private String m_chartTitle = null;
    private String m_chartXAxisTitle = null;
    private String m_chartYAxisTitle = null;
    private String m_secondAxisChartYAxisTitle = null;

    private int m_maxYValue = DEFAULT_MAX_Y_VALUE;
    private int m_secondAxisMaxYValue = DEFAULT_MAX_Y_VALUE;

    private String m_inputPath = null;

    private int m_width = DEFAULT_WIDTH;
    private int m_height = DEFAULT_HEIGHT;

    private boolean m_barChart = false;
    private boolean m_secondAxisBarChart = false;

    private int m_lineWeight = -1;
    private int m_secondAxisLineWeight = -1;

    private boolean m_dataPoints = false;
    private boolean m_secondAxisDataPoints = false;

    private String[] m_seriesTitles = null;
    private String[] m_secondAxisSeriesTitles = null;

    private boolean m_cliServer = false;

    /* ========================================================================
     *
     * Constructors
     */

    /* ========================================================================
     *
     * Static methods
     */

    /* ========================================================================
     *
     * Public methods
     */

    public int getDataSeparatorType() {
        return m_dataSeparatorType;
    }

    public void setDataSeparatorType(int dataSeparatorType) {
        m_dataSeparatorType = dataSeparatorType;
    }

    public String getDateFormat() {
        return m_dateFormat;
    }

    public void setDateFormat(String dateFormat) {
        m_dateFormat = dateFormat;
    }

    public boolean hasHeaderRow() {
        return m_headerRow;
    }

    public void setHeaderRow(boolean hasHeaderRow) {
        m_headerRow = hasHeaderRow;
    }

    public boolean ignoreMissingColumns() {
        return m_ignoreMissingColumns;
    }

    public void setIgnoreMissingColumns(boolean ignoreMissingColumns) {
        m_ignoreMissingColumns = ignoreMissingColumns;
    }

    public boolean ignoreDuplicateValues() {
        return m_ignoreDuplicateValues;
    }

    public void setIgnoreDuplicateValues(boolean ignoreDuplicateValues) {
        m_ignoreDuplicateValues = ignoreDuplicateValues;
    }

    public int[] getColumnIndexes() {
        return m_columnIndexes;
    }

    public void setColumnIndexes(int[] columnIndexes) {
        m_columnIndexes = columnIndexes;
    }

    public int[] getSecondAxisColumnIndexes() {
        return m_secondAxisColumnIndexes;
    }

    public void setSecondAxisColumnIndexes(int[] secondAxisColumnIndexes) {
        m_secondAxisColumnIndexes = secondAxisColumnIndexes;
    }

    public int getChartXType() {
        return m_chartXType;
    }

    public void setChartXType(int chartXType) {
        m_chartXType = chartXType;
    }

    public String getFileOutputPath() {
        return m_fileOutputPath;
    }

    public void setFileOutputPath(String fileOutputPath) {
        m_fileOutputPath = fileOutputPath;
    }

    public String getChartTitle() {
        return m_chartTitle;
    }

    public void setChartTitle(String chartTitle) {
        m_chartTitle = chartTitle;
    }

    public String getChartXAxisTitle() {
        return m_chartXAxisTitle;
    }

    public void setChartXAxisTitle(String chartXAxisTitle) {
        m_chartXAxisTitle = chartXAxisTitle;
    }

    public String getChartYAxisTitle() {
        return m_chartYAxisTitle;
    }

    public void setChartYAxisTitle(String chartYAxisTitle) {
        m_chartYAxisTitle = chartYAxisTitle;
    }

    public String getSecondAxisChartYAxisTitle() {
        return m_secondAxisChartYAxisTitle;
    }

    public void setSecondAxisChartYAxisTitle(String secondAxisChartYAxisTitle) {
        m_secondAxisChartYAxisTitle = secondAxisChartYAxisTitle;
    }

    public int getMaxYValue() {
        return m_maxYValue;
    }

    public void setMaxYValue(int maxYValue) {
        m_maxYValue = maxYValue;
    }

    public int getSecondAxisMaxYValue() {
        return m_secondAxisMaxYValue;
    }

    public void setSecondAxisMaxYValue(int secondAxisMaxYValue) {
        m_secondAxisMaxYValue = secondAxisMaxYValue;
    }

    public String getInputPath() {
        return m_inputPath;
    }

    public void setInputPath(String inputPath) {
        m_inputPath = inputPath;
    }

    public int getChartWidth() {
        return m_width;
    }

    public void setChartWidth(int width) {
        m_width = width;
    }

    public int getChartHeight() {
        return m_height;
    }

    public void setChartHeight(int height) {
        m_height = height;
    }

    public boolean isBarChart() {
        return m_barChart;
    }

    public void setBarChart(boolean barChart) {
        m_barChart = barChart;
    }

    public boolean isSecondAxisBarChart() {
        return m_secondAxisBarChart;
    }

    public void setSecondAxisBarChart(boolean secondAxisBarChart) {
        m_secondAxisBarChart = secondAxisBarChart;
    }

    public int getLineWeight() {
        return m_lineWeight;
    }

    public void setLineWeight(int lineWeight) {
        m_lineWeight = lineWeight;
    }

    public int getSecondAxisLineWeight() {
        return m_secondAxisLineWeight;
    }

    public void setSecondAxisLineWeight(int secondAxisLineWeight) {
        m_secondAxisLineWeight = secondAxisLineWeight;
    }

    public boolean hasDataPoints() {
        return m_dataPoints;
    }

    public void setDataPoints(boolean dataPoints) {
        m_dataPoints = dataPoints;
    }

    public boolean hasSecondAxisDataPoints() {
        return m_secondAxisDataPoints;
    }

    public void setSecondAxisDataPoints(boolean secondAxisDataPoints) {
        m_secondAxisDataPoints = secondAxisDataPoints;
    }

    public String[] getSeriesTitles() {
        return m_seriesTitles;
    }

    public void setSeriesTitles(String[] seriesTitles) {
        m_seriesTitles = seriesTitles;
    }

    public String[] getSecondAxisSeriesTitles() {
        return m_secondAxisSeriesTitles;
    }

    public void setSecondAxisSeriesTitles(String[] secondAxisSeriesTitles) {
        m_secondAxisSeriesTitles = secondAxisSeriesTitles;
    }

    public boolean isCliServer() {
        return m_cliServer;
    }

    public void setCliServer(boolean cliServer) {
        m_cliServer = cliServer;
    }

    /* ========================================================================
     *
     * Protected / package-private methods
     */

    /* ========================================================================
     *
     * Private methods
     */
}