/*
 * Copyright (c) 2005 Dialect Solutions Holdings. All rights reserved.
 */
package net.sf.clichart.main.cliserver;

import net.sf.clichart.chart.OptionsBean;
import net.sf.clichart.main.InvalidOptionsException;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

/**
 * Abstract base class for option setters, using reflection to set the property on the Options
 *
 * @author johnd
 */
public abstract class AbstractOptionSetter implements OptionSetter {

    /* ========================================================================
     *
     * Class (static) variables.
     */

    /* ========================================================================
     *
     * Instance variables.
     */

    private final String m_setterName;

    /* ========================================================================
     *
     * Constructors
     */

    public AbstractOptionSetter(String setterName) {
        m_setterName = setterName;
    }


    /* ========================================================================
     *
     * Static methods
     */

    /* ========================================================================
     *
     * Public methods
     */
    public void setOption(OptionsBean options, String command, String argument) throws InvalidOptionsException {
        try {
            Method method = OptionsBean.class.getDeclaredMethod(m_setterName, getParameterType());
            setValue(options, method, command, argument);
        } catch (NoSuchMethodException e) {
            throw new RuntimeException("Unexpected error setting field value", e);
        } catch (IllegalAccessException e) {
            throw new RuntimeException("Unexpected error setting field value", e);
        } catch (InvocationTargetException e) {
            throw new RuntimeException("Unexpected error setting field value", e);
        }
    }

    /* ========================================================================
     *
     * Protected / package-private methods
     */

    protected abstract void setValue(OptionsBean options, Method method, String command, String argument)
            throws IllegalAccessException, InvalidOptionsException, InvocationTargetException;


    protected abstract Class[] getParameterType();

    /* ========================================================================
     *
     * Private methods
     */

}