#!/usr/bin/env python

"""
An attempt to run a smoke test of an installed clichart, in a way that will work
on (and test) Linux, Cygwin and base Windows.
"""

import sys, os, shutil

JAVA_VERSIONS = ('1.4', '1.5', '1.6')
# contains (Linux home, Windows home) keyed against version number.  
JAVA_HOMES = {
    '1.4': ('/usr/java/j2sdk1.4.2_13', 'F:\\Java\\jdk1.4.2_02'),
    '1.5': ('/usr/java/jdk1.5.0_10', 'C:\\Program Files\\Java\\jdk1.5.0_11'),
    '1.6': ('/usr/java/jdk1.6.0', 'invalidPath')
}

OUTPUT_DIR = '../output'


# ----------------------------------------------------------------------------
def usage(msg = None):
    if msg:
        print
        print msg

    print """Tests the clichart install in the *current* directory"""
    sys.exit(1)

# ----------------------------------------------------------------------------
def setJavaHome(javaVersion):
    javaHomes = JAVA_HOMES[javaVersion]
    if sys.platform.find('linux') >= 0:
        javaHome = javaHomes[0]
    else:
        javaHome = javaHomes[1]
    if javaHome is not None:
        print 'Setting Java Home to', javaHome
        os.putenv('JAVA_HOME', javaHome)

# ----------------------------------------------------------------------------
def outputOption(filename, javaVersion):
    if not filename:
        return ''
    name, ext = os.path.splitext(filename)
    return '-o %s/%s-%s%s' % (OUTPUT_DIR, name, javaVersion, ext)

# ----------------------------------------------------------------------------
def chart(title, cmdLine, inputFile, outputFile, javaVersion):
    print '-------', title

    realCmdLine = cmdLine.replace('$OUTPUT', outputOption(outputFile, javaVersion)) \
            .replace('$INPUT', 'samples/%s' % inputFile) \
            .replace('$TITLE', '"%s"' % title)
    #print '  ', realCmdLine
    os.system(realCmdLine)

# ----------------------------------------------------------------------------
if not os.path.exists('bin/clichart'):
    usage()

if os.path.exists(OUTPUT_DIR):
    shutil.rmtree(OUTPUT_DIR)
os.mkdir(OUTPUT_DIR)

for javaVersion in JAVA_VERSIONS:
    print '========== Java %s ===============' % javaVersion
    setJavaHome(javaVersion)

    os.putenv('PATH', 'bin%s%s' % (os.pathsep, os.getenv('PATH')))

    # DEBUG
    #chart('Check path', 'clichart -h', '',
    #        'SystemTemps.png', javaVersion)
    #sys.exit()

    chart('Simple system temps', 'clichart -fcl 0,1,2 $OUTPUT $INPUT', 'SystemTemps.csv',
            'SystemTemps.png', javaVersion)

    chart('System temps with titles', 'clichart -f -c -l 0,1,2 -t $TITLE -y "Degrees C" $OUTPUT $INPUT',
            'SystemTemps.csv', 'SystemTemps-2.png', javaVersion)

    chart('Temps/fan speeds with second axis',
            'clichart -fcl 0,1,2 -t $TITLE -y "Degrees C" $OUTPUT --columnlist2 3,4 --ytitle2 RPM $INPUT',
            'SystemTemps.csv', 'SystemTemps-2axis.png', javaVersion)

    chart('Temps/fan speeds with second axis bar',
            'clichart -fcl 0,1,2 -t $TITLE -y "Degrees C" $OUTPUT --columnlist2 3,4 --bar2 --ytitle2 RPM $INPUT',
            'SystemTemps.csv', 'SystemTemps-2axisbar.png', javaVersion)

    chart('Temps/fan speeds with second axis bar and line embellishments',
            'clichart -fcl 0,1,2 -t $TITLE -y "Degrees C" $OUTPUT --columnlist2 3,4 --bar2 --ytitle2 RPM ' \
            + '--datapoints --lineweight 2 --lineweight2 5 $INPUT',
            'SystemTemps.csv', 'SystemTemps-2axisbarembellished.png', javaVersion)

    chart('System log - memory and threads',
            'linestats.py -m VMStatusLogger -k s:0:5 -v f:4 -v f:7 -v f:11 -l k,0:min,1:min,2:min $INPUT ' \
            + '| clichart -l 0,1,2,3 -t $TITLE $OUTPUT', 'System.log', 'MemoryThreads.png', javaVersion)

    chart('System log - memory and threads, with mid to strip out data',
            'linestats.py -m VMStatusLogger -k s:0:5 -v f:4 -v f:7 -v f:11 -l k,0:min,1:min,2:min $INPUT ' \
            + '| bin/mid.py 1:1 31:-1 | clichart -l 0,1,2,3 -t $TITLE $OUTPUT', 'System.log',
            'MemoryThreads-2.png', javaVersion)

    chart('System log - transactions',
            'linestats.py -m Transaction -k s:0:5 -l k:cnt,k $INPUT ' \
            + '| clichart -l 1,0 -t $TITLE $OUTPUT', 'System.log', 'Transactions.png', javaVersion)

    chart('System log - transaction amounts',
            'linestats.py -m Transaction -k s:0:5 -v "r:A:(\\d+)" -c -l k,0:min,0:av,0:max ' \
            + ' -f "Timestamp, Min, Average, Max" $INPUT ' \
            + '| clichart -cl 0,1,2,3 -f -t $TITLE -y "Transaction amount (cents)" $OUTPUT',
            'System.log', 'Transactions-2.png', javaVersion)

    chart('System log - log message rates',
            'discretestats.py -k s:0:5 -v f:1 -c $INPUT ' \
            + '| clichart -cl 0,2,3 -f -t $TITLE -y "Messages per minute" $OUTPUT',
            'System.log', 'MessageRates.png', javaVersion)

    chart('System temps with value axis',
            'clichart -cfvl 2,4 -x "Case temperature" $OUTPUT --columnlist2 3,4 --bar2 --ytitle2 RPM ' \
            + '--datapoints --lineweight 2 --lineweight2 5 -t $TITLE $INPUT',
            'SystemTemps.csv', 'SystemTemps-value.png', javaVersion)

    chart('Repeat transactions, but with JPEG output',
            'linestats.py -m Transaction -k s:0:5 -l k:cnt,k $INPUT ' \
            + '| clichart -l 1,0 -t $TITLE $OUTPUT', 'System.log', 'Transactions.jpg', javaVersion)

    chart('Repeat transactions, but with larger charts (note diff option styles)',
            'linestats.py -m Transaction -k s:0:5 -l k:cnt,k $INPUT ' \
            + '| clichart -l 1,0 -t $TITLE -w 1024 --height 800 $OUTPUT',
            'System.log', 'Transactions-big.png', javaVersion)

    chart('Testing interactive! (just close window if it looks OK)',
            'linestats.py -m Transaction -k s:0:5 -l k:cnt,k $INPUT ' \
            + '| clichart -l 1,0 -t $TITLE ', 'System.log', None, javaVersion)
