#!/usr/bin/env python

"""
(C) Copyright 2007, by John Dickson

Project Info:  http://clichart.sourceforge.net/

This library is free software; you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2.1 of the License, or
(at your option) any later version.

This library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
USA.

$Id: sumCsvCols.py 542 2007-04-01 02:50:42Z johnd $


Simple script to sum 1 or more columns in a CSV file (for generating
summaries of stats from log scripts).

NOTE: This script is not yet supported as part of clichart.

See usage()
"""

import sys, getopt

# ===============================================================
def usage(msg = None):
    if msg:
        print msg
        print
    print """
Simple script to sum 1 or more columns in a CSV file (for generating
summaries of stats from log scripts)

Usage: sumCsvCols.py [options] colNum+

Note: Columns number from 0

Options:
  -t            CSV input contains a title (header) row
  -f inputFile  Take CSV input from this file (otherwise stdin)
  -h            Show help and exit
  -m            Instead of totals, print maxima
"""
    sys.exit(1)

# ===============================================================
if __name__ == '__main__':
    opts, args = getopt.getopt(sys.argv[1:], 'f:hmt')
    inFile = sys.stdin
    skipFirst = False
    isTotals = True
    for opt, arg in opts:
        if opt == '-h':
            usage()
        elif opt == '-f':
            inFile = open(arg)
        elif opt == '-t':
            skipFirst = True
        elif opt == '-m':
            isTotals = False
    if len(args) < 1:
        usage('Column numbers required')
    colNums = [int(arg) for arg in args]

    totals = [0.0] * (max(colNums) + 1)
    isFirstLine = True
    for line in inFile:
        #print line
        if isFirstLine and skipFirst:
            isFirstLine = False
            continue
        cpts = line.split(',')
        #print cpts
        for colNum in colNums:
            if isTotals:
                totals[colNum] += float(cpts[colNum].strip())
            else:   # maxima
                totals[colNum] = max(totals[colNum], float(cpts[colNum].strip()))
    for colNum in colNums:
        print '%s  ' % totals[colNum],

